@@ -1,7 +1,6 @@
 setClass("STT",  # space-time trajectory/ies without data values
   contains = "ST", 
-  #slots = c(traj = "list"),
-  representation(traj = "list"),
+  slots = c(traj = "list"),
   validity = function(object) {
     stopifnot(length(object@traj) > 0)
 	stopifnot(length(object@sp) == 2)
@@ -14,8 +13,7 @@ setClass("STT",  # space-time trajectory/ies without data values
 
 setClass("STTDF",  # space-time trajectory/ies with data values
   contains = "STT", 
-  #slots = c(data = "data.frame"),
-  representation(data = "data.frame"),
+  slots = c(data = "data.frame"),
   validity = function(object) {
 	stopifnot(sum(sapply(object@traj, length)) == nrow(object@data))
     .checkAttrIsUnique(object@sp, object@time, object@data)
